/*******************************************************************************
 * Copyright (C) 2017 François PETITJEAN
 * Contributors:
 * 	François PETITJEAN
 *  Germain FORESTIER
 * 
 * This file is part of ForestierAIIM2017. 
 * This is a program related to the paper "Automatic matching of surgeries to predict surgeons' 
 * next actions" published in Artificial Intelligence in Medicine" : 
 * http://dx.doi.org/10.1016/j.artmed.2017.03.007
 * 
 * ForestierAIIM2017 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 * 
 * ForestierAIIM2017 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with ForestierAIIM2017.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
package items;
import static java.lang.Math.abs;
public class MonoDoubleItemSet extends Itemset implements java.io.Serializable {
	private static final long serialVersionUID = 5103879297281957601L;
	
	double value;
	
	public MonoDoubleItemSet(double value){
		this.value = value;
	}
	
	@Override
	public Itemset clone() {
		return new MonoDoubleItemSet(value);
	}

	@Override
	public double distance(Itemset o) {
		MonoDoubleItemSet o1 = (MonoDoubleItemSet)o;
		return abs(o1.value-value);
	}

	@Override
	public Itemset mean(Itemset[] tab) {
		if (tab.length < 1) {
			throw new RuntimeException("Empty tab");
		}
		double sum = 0.0;
		for (Itemset itemset : tab) {
			MonoDoubleItemSet item = (MonoDoubleItemSet)itemset;
			sum += item.value;
		}
		return new MonoDoubleItemSet(sum / tab.length);
	}

	@Override
	public String toString() {
		return new Double(value).toString();
	}
	
	public double getValue(){
		return value;
	}
}
