/*******************************************************************************
 * Copyright (C) 2017 François PETITJEAN
 * Contributors:
 * 	François PETITJEAN
 *  Germain FORESTIER
 * 
 * This file is part of ForestierAIIM2017. 
 * This is a program related to the paper "Automatic matching of surgeries to predict surgeons' 
 * next actions" published in Artificial Intelligence in Medicine" : 
 * http://dx.doi.org/10.1016/j.artmed.2017.03.007
 * 
 * ForestierAIIM2017 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 * 
 * ForestierAIIM2017 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with ForestierAIIM2017.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
package items;

import java.util.HashMap;


public class MonoItemSet extends Itemset {
	String letter;
	
	public MonoItemSet(String letter){
		this.letter = letter;
	}
	@Override
	public Itemset clone() {
		return new MonoItemSet(new String(letter));
	}

	@Override
	public double distance(Itemset o) {
		MonoItemSet mono = (MonoItemSet)o;
		return (letter.equals(mono.letter))?0.0:1.0;
	}

	@Override
	/**
	 * vote
	 */
	public Itemset mean(Itemset[] tab) {
		HashMap<String, Integer> map = new HashMap<String, Integer>();
		int maxCount = 0;
		String maxKey=null;
		for(Itemset itemset:tab){
			String key = ((MonoItemSet)itemset).letter;
			Integer count = map.get(key);
			Integer newCount ;
			if(count == null){
				newCount = 1;
			}else{
				newCount = count+1;
			}
			if(newCount>maxCount){
				maxCount = newCount;
				maxKey = key;
			}
			map.put(key, newCount);
		}
		return new MonoItemSet(maxKey);
	}

	@Override
	public String toString() {
		return letter;
	}
}
